(*
This package may be distributed freely, but is copyright
by Lafayette College, 1994.


*)
BeginPackage["Arclength`"]

segments::usage="segments[{f[t],g[t]},{t,tmin,tmax},n] plots the
    parametric curve and n line segments which can be used to
    approximate the length of the curve."

legs::usage="legs[{f[t],g[t]},{t,tmin,tmax},n] plots the parametric
	curve and shows how the sum of the lengths of the legs
	of n right triangles might be used to estimate the length
	of the curve."

estimate::usage="estimate[{f[t],g[t]},{t,tmin,tmax},n] estimates the
    length of the curve given parametrically by x = f(t), y = g(t),
    over the interval tmin < t < tmax, using n subdivisions of the
    arc."

Begin["`Private`"]

segments[funclist_,paramlist_,n_,options___] :=
  Block[{tmin, tmax, plotcurve, plotlines, points,
    stepsize, param},
    param = paramlist[[1]];
    tmin = paramlist[[2]]; tmax = paramlist[[3]];
    stepsize = (tmax - tmin)/n;
    plotcurve = ParametricPlot[Evaluate[funclist/.param->t],
      {t,tmin,tmax},PlotStyle->RGBColor[1,0,0],
      DisplayFunction->Identity];
    plotlines = Graphics[{RGBColor[0,0,1], Line[Table[
      funclist/.param->t,
      {t, tmin, tmax, stepsize} ]]}];
    points = Table[Graphics[{RGBColor[0,0,1], Point[
      funclist/.param->t ]}],
      {t, tmin, tmax, stepsize}];
    Show[plotcurve,plotlines, points,options,
      DisplayFunction->$DisplayFunction]
    ]

legs[funclist_,paramlist_,n_,options___] :=
  Block[{tmin, tmax, plotcurve, plotlines, points, param},
    param = paramlist[[1]];
    tmin = paramlist[[2]];
    tmax = paramlist[[3]];
    stepsize = (tmax-tmin)/n;
    plotcurve = ParametricPlot[Evaluate[funclist/.param->t],
      {t,tmin,tmax},PlotStyle->RGBColor[1,0,0],
      DisplayFunction->Identity];
    plotlines = Graphics[{RGBColor[0,0,1], Table[Line[
      {funclist/. param -> t,
      {funclist[[1]] /. param -> (t+stepsize),
       funclist[[2]] /. param -> t},
       funclist /. param -> (t+stepsize)}],
      {t, tmin, tmax-stepsize, stepsize}]}
      ];
    points = Table[Graphics[{RGBColor[0,0,1], Point[
      funclist /. param -> t ]}],
      {t, tmin, tmax, stepsize}];
    Show[plotcurve, points, plotlines, options,
      DisplayFunction->$DisplayFunction]
    ]

estimate[funclist_,paramlist_,n_] :=
  Block[{tmin, tmax, h, param, k},
    param = paramlist[[1]];
    tmin = paramlist[[2]];
    tmax = paramlist[[3]];
    h = (tmax - tmin)/n;
    Sum[N[Sqrt[
      ((funclist[[1]] /. param -> k h) -
       (funclist[[1]] /. param -> (k-1)h))^2
    + ((funclist[[2]] /. param -> k h) -
       (funclist[[2]] /. param -> (k-1)h))^2]],
      {k,1,n}]
    ]


End[(* "`Private`" *)]
EndPackage[ ]
