(*
This package may be distributed freely, but is copyright
by Lafayette College, 1994.


*)
BeginPackage["DEGraphics`"]

DEfield::usage =
"DEfield[f[x,y],{x,xmin,xmax},{y,ymin,ymax},(initcond)]
        shows the direction field of dy/dx = f(x,y).  If initial
        conditions are specified, NDSolve is used to plot
        the solution through the given point."

plotsol::usage =
"plotsol[f[x,y],{x,xmin,xmax},{y,ymin,ymax},initcond]
         plots solutions of dy/dx = f(x,y) through the point(s)
         given in initcond.  Euler's method is used to compute the
         approximate solutions."

solcurve::usage =
"solcurve[f[x,y],{x,xmin,xmax},{y,ymin,ymax},{x0,y0}]
         plots the solution of dy/dx = f(x,y) passing through the
         initial conditon (x0,y0). The Mathematica routine NDSolve
         is used to compute the numerical solution."

dirfield::usage =
"dirfield[f[x,y],{x,xmin,xmax},{y,ymin,ymax}] plots the direction
         field of dy/dx = f(x,y)."

euler::usage =
"euler[equation,{x,xinit,xlast,deltax},{y,yinit}]
         computes the Euler approximation of the solution of the
         initial value problem  dy/dx = func(x,y); y(xinit) = yinit,
         on the interval [xinit,xlast] using a step size of deltax."

eulerdemo::usage =
"Why doesn't this work?"

Begin["`Private`"]

  plotsol[func_, xlist_, ylist_, initcond_,nsteps_:25] :=
      Block[{length, j, k, n, init, step, numstepback, numstepforth, xforth,
             xback, yforth, yback, plot, xmin, xmax, ymin, ymax,
             paramx, paramy, color},
        Clear[length, j, k, n, init, step, numstepback, numstepforth,
              xforth, xback, yforth, yback, plot, totalplot];
        paramx = xlist[[1]];
        xmin = xlist[[2]];
        xmax = xlist[[3]];
        paramy = ylist[[1]];
        ymin = ylist[[2]];
        ymax = ylist[[3]];
        step = N[(xmax-xmin)/25];
        init = initcond;
        length = Length[init];
        color[n_] :=
          If[length > 1,
          RGBColor[(length-n)/(length-0.999),0,(n-1)/(length - 0.999)],
          RGBColor[1,0,0]];
        For[j = 1, j <= length, j++,
          Clear[xforth, xback, yforth, yback];
          numstepback = Round[(xmin - init[[j]][[1]])/step];
          numstepforth = Round[(xmax - init[[j]][[1]])/step];
          xforth[0] = init[[j]][[1]];
          xforth[k_] := xforth[k] = xforth[k - 1] + step;
          yforth[0] = init[[j]][[2]];
          yforth[k_] := yforth[k] = If[Abs[yforth[k-1]] < 200,
            yforth[k - 1] + step N[
            func /. {paramx -> xforth[k - 1], paramy -> yforth[k - 1]}],
            yforth[k-1]];
          xback[0] = init[[j]][[1]];
          xback[k_] := xback[k] = xback[k - 1] - step;
          yback[0] = init[[j]][[2]];
          yback[k_] := yback[k] = If[Abs[yback[k-1]] < 200,
            yback[k - 1] - step N[
            func /. {paramx -> xback[k - 1], paramy -> yback[k - 1]}],
            yback[k-1]];
          plot[j] =
            Show[
              ListPlot[Table[{xforth[k], yforth[k]}, {k, 0, numstepforth}],
                PlotRange -> {ymin, ymax}, PlotJoined -> True,
                DisplayFunction -> Identity, PlotStyle->color[j]],
              ListPlot[Table[{xback[k], yback[k]}, {k, 0, -numstepback}],
                PlotRange -> {ymin, ymax}, PlotJoined -> True,
                DisplayFunction -> Identity, PlotStyle->color[j]]
            ]
        ];
          totalplot = Table[plot[n], {n, 1, length}]
      ]
  
  solcurve[func_,xlist_,ylist_,initcond_,options___]:=
      Block[{xp,yp,x,y,xmin,ymin,xmax,ymax,x0,y0},
        xp=xlist[[1]];
        yp=ylist[[1]];
        xmin=xlist[[2]];
        ymin=ylist[[2]];
        xmax=xlist[[3]];
        ymax=ylist[[3]];
        x0=initcond[[1]];
        y0=initcond[[2]];
         Plot[Evaluate[(y[x] /. {y->yp,x->xp}) /. NDSolve[
          {y'[x] == func /. {x->xp,yp->yp[xp],y->yp},
          y[x0]==y0/.y->yp},y/.y->yp,xlist]],
          Evaluate[{x/.x->xp,xmin,xmax}],options,
          PlotRange->{ymin,ymax}]
        ]           

  dirfield[func_, xlist_, ylist_, numlines_:Automatic] :=
      Block[{x, y, r, s, u, n, scale, j, k, slope, deltax, deltay,
             xmin, xmax, ymin, ymax, paramx, paramy},
        Clear[lines];
        paramx = xlist[[1]];
        xmin = xlist[[2]];
        xmax = xlist[[3]];
        paramy = ylist[[1]];
        ymin = ylist[[2]];
        ymax = ylist[[3]];
        If[numlines === Automatic, n = 20, n = numlines];
        scale = 4.;
        r = N[(xmax - xmin)/n];
        s = N[(ymax - ymin)/n];
        u = Min[r, s]/scale;
        x = Table[xmin + (j - 1/2) r, {j, 1, n}];
        y = Table[ymin + (k - 1/2) s, {k, 1, n}];
        slope = Table[N[func /. {paramx -> x[[j]], paramy -> y[[k]]}],
           {j, 1, n}, {k, 1, n}];
        deltax = Table[u/Sqrt[1 + slope[[j]][[k]]^2], {j, 1, n}, {k, 1, n}];
        deltay = Table[slope[[j]][[k]] deltax[[j]][[k]],
          {j, 1, n}, {k, 1, n}];
        lines =
          Table[Graphics[Line[
            {{x[[j]] - deltax[[j]][[k]], y[[k]] - deltay[[j]][[k]]},
            {x[[j]] + deltax[[j]][[k]],  y[[k]] + deltay[[j]][[k]]}}]
            ],
            {j, 1, n}, {k, 1, n}]
        ]

  DEfield[func_, xlist_, ylist_, initcond_:Automatic,options___] :=
    Module[{q,traject,ymin,ymax},
    If[initcond === Automatic, dirfield[func,xlist,ylist];
      Show[lines, options, Axes->Automatic, Frame->True],
      ymin=ylist[[2]];
      ymax=ylist[[3]];
      dirfield[func,xlist,ylist];
    If[NumberQ[q /. q->initcond[[1]]],
      traject=solcurve[func,xlist,ylist,initcond,
          DisplayFunction->Identity];
      Show[lines, traject, options,PlotRange->{ymin,ymax},
          Axes->Automatic,Frame->True,
          DisplayFunction->$DisplayFunction],
      traject=Table[solcurve[func,xlist,ylist,initcond[[i]],
          DisplayFunction->Identity],{i,Length[initcond]}];
      Show[Prepend[traject,lines], options,PlotRange->{ymin,ymax},
          Axes->Automatic,Frame->True,
          DisplayFunction->$DisplayFunction],
     ]
     ]
    ]


  euler[equation_,xlist_,ylist_] :=

    Block[{xinit, xlast, deltax, yinit, numstep, x, y, func,
           paramx, paramy},

      (* Test if dependent variable is identified properly. *)

      If[SameQ[Last[First[equation]], ylist[[1]] ],

        func = Last[equation];
        paramx = xlist[[1]];
        xinit = N[xlist[[2]]];
        xlast = N[xlist[[3]]];
        deltax = N[xlist[[4]]];
        paramy = ylist[[1]];
        yinit = N[ylist[[2]]];

      (* test if xlast - xinit and deltax agree in sign *)

        If[(xlast - xinit) deltax < 0,
          Print[ ];
          Print["Have you entered the parameters on x correctly?"];
          Return[ ] ];

        numstep = Round[(xlast - xinit)/deltax];

        x[0] := xinit;
        x[n_] := x[n] = x[n-1] + deltax;
        y[0] := yinit;
        y[n_] := y[n]
          = If[y[n-1] < 20000,
              y[n-1] + deltax N[func /. {paramx -> x[n-1],
              paramy -> y[n-1]} ],
              y[n-1] ];
        Table[{x[n],y[n]}, {n,0,numstep}],

      (* Return error message if the variables are incorrect." *)

      Print[ ];
      Print["Check the syntax of your command."]]

      ]  (* end of block for function euler*)

  eulerdemo[equation_, xlist_, ylist_] :=
    Block[{eulersol, numstep, x, y, j, k, func, plot, lines, plotrange,
      ymin, ymax, newylist, field, color},
      Clear[eulersol, numstep, x, y, j, k, func];
      func = Last[equation];
      xmin = xlist[[2]];
      xmax = xlist[[3]];
      eulersol = euler[equation,xlist,ylist];
      numstep = Length[eulersol] - 1;
      color[k_] := If[numstep == 1, RGBColor[1,0,0],
        RGBColor[(numstep-1-k)/(numstep-1),0,k/(numstep-1)]];
      x[k_] := eulersol[[k+1]][[1]];
      y[k_] := eulersol[[k+1]][[2]];
      ymin = Min[Table[y[k],{k,0,numstep}]];
      ymax = Max[Table[y[k],{k,0,numstep}]];
      plotrange = {{xmin, xmax}, {ymin, ymax}};
      newylist = {ylist[[1]],ymin,ymax};
      field = dirfield[func, xlist, newylist, 10];
      lines =
        Table[Graphics[color[j], Line[
          { {x[j], y[j]}, {x[j+1], y[j+1]} }] ],
          {j, 0, numstep-1} ];
      plot[n_] := plot[n] = Show[Table[lines[[j]], {j, 1, n}],
        DisplayFunction -> Identity, PlotRange -> plotrange];
      Table[Show[{plot[k], field}, Axes -> Automatic,
        DisplayFunction -> $DisplayFunction], {k, 1, numstep}]
    ]   (* End of procedure eulerdemo. *)


End[(* "`Private`" *)]
EndPackage[]
