(*Path Integration Package*)

BeginPackage["PathIntegrals`"]

ScalarPIntegrate::usage = "ScalarPIntegrate[ftn,{x[t],y[t]},{t,t0,t1}]
computes the integral of the real-valued function ftn along the contour
parametrized by {x[t],y[t]} from t=t0 to t=t1. The command works any
dimension two or higher."

VectorPIntegrate::usage = "VectorPIntegrate[vfld,{x[t],y[t]},{t,t0,t1}]
computes the integral of the vector field vfld along the contour
parametrized by {x[t],y[t]} from t=t0 to t=t1. The command works any
dimension two or higher."

NScalarPIntegrate::usage = "NScalarPIntegrate[ftn,{x[t],y[t]},{t,t0,t1},(options)]
computes a numerical approximation to the integral of the real-valued function ftn along the contour
parametrized by {x[t],y[t]} from t=t0 to t=t1. The command works any
dimension two or higher."

NVectorPIntegrate::usage = "nVectorPIntegrate[vfld,{x[t],y[t]},{t,t0,t1},(options)]
computes a numerical approximation to the integral of the vector field vfld along the contour
parametrized by {x[t],y[t]} from t=t0 to t=t1. The command works any
dimension two or higher."
(*


*)
Begin["`Private`"]
(*


*)
ScalarPIntegrate[f_,param_,{t_,t0_,t1_}]:=
Integrate[Apply[f,param]*
Sqrt[Apply[Plus,Map[#^2 &,Map[D[#,t] &,param]]]],{t,t0,t1}]
(*


*)
VectorPIntegrate[f_,param_,{t_,t0_,t1_}]:=
Integrate[Apply[Plus,Dot[Apply[f,param],
Map[D[#,t] &,param]]],{t,t0,t1}]
(*


*)
NScalarPIntegrate[f_,param_,{t_,t0_,t1_},options___]:=
NIntegrate[Apply[f,param]*
Sqrt[Apply[Plus,Map[#^2 &,Map[D[#,t] &,param]]]],{t,t0,t1},options]
(*


*)
NVectorPIntegrate[f_,param_,{t_,t0_,t1_},options___]:=
NIntegrate[Apply[Plus,Dot[Apply[f,param],
Map[D[#,t] &,param]]],{t,t0,t1},options]
(*


*)
End[ ] (* Private Context*)

EndPackage[ ]
