(*
This package may be distributed freely, but is copyright
by Lafayette College, 1994.


*)
BeginPackage["RevolutionGraphics`"]

XRevolve::usage = "XRevolve[f[x],{x,xmin,xmax}] revolves the
graph of z = f[x] over the interval (xmin,xmax) about the
x-axis.  XRevolve[f[x], {x, xmin, xmax}, {thetamin, thetamax},
(options)] revolves the graph through the angles (thetamin,
thetamax); theta=0 when the graph falls in the xz-plane. 
The options may be included or not."

YRevolve::usage = "YRevolve[f[x],{x,xmin,xmax}] revolves the
graph of y = f[x] over the interval (xmin,xmax) about the
y-axis.  YRevolve[f[x], {x, xmin, xmax}, {thetamin, thetamax},
(options)] revolves the graph through the angles (thetamin,
thetamax); theta=0 when the graph falls in the xy-plane. 
The options may be included or not."

Begin["`Private`"]

XRevolve[ftn_,paramlist_,thetalist_:{0,2Pi},options___]:=
    Module[{param,pmax,pmin,t,tmax,tmin,x},
    param=paramlist[[1]];
    pmax=paramlist[[3]];
    pmin=paramlist[[2]];
    tmax=thetalist[[2]];
    tmin=thetalist[[1]];
    ParametricPlot3D[Evaluate[
        {x,(ftn/.param->x)Sin[t],(ftn/.param->x)Cos[t]} ],
        {x,pmin,pmax},{t,tmin,tmax},options]
    ];

YRevolve[ftn_,paramlist_,thetalist_:{0,2Pi},options___]:=
    Module[{param,pmax,pmin,t,tmax,tmin,x},
    param=paramlist[[1]];
    pmax=paramlist[[3]];
    pmin=paramlist[[2]];
    tmax=thetalist[[2]];
    tmin=thetalist[[1]];
    ParametricPlot3D[Evaluate[
        {x Cos[t],x Sin[t],(ftn/.param->x)} ],
        {x,pmin,pmax},{t,tmin,tmax},options]
    ];

End[(*Private Context*)]

EndPackage[]
